@@ -166,18 +166,42 @@ test_that("summary", {
 
   expect_equal(
     names(result$diagnostics_summary),
-    c("ingredient_concept_id","ingredient",
-      "n_records",
-      "proportion_of_records_with_dose_form",
-      "proportion_of_records_by_route_type",
+    c("ingredient", "ingredient_concept_id", "n_records",
       "proportion_of_records_by_drug_type",
-      "proportion_of_records_with_negative_drug_exposure_days",
-      "median_drug_exposure_days_q05_q95",
-      "proportion_of_records_missing_days_supply_or_dates",
-      "median_quantity_q05_q95",
+      "proportion_of_records_by_route_type",
+      "proportion_of_records_with_dose_form",
       "proportion_of_records_missing_denominator_unit_concept_id",
       "median_amount_value_q05_q95",
+      "median_quantity_q05_q95",
+      "median_drug_exposure_days_q05_q95",
+      "proportion_of_records_with_negative_drug_exposure_days",
       "result_obscured"))
 
   DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
 })
+
+test_that("subset on specific concepts", {
+  cdm <- getEunomiaCdm(1125315)
+  result_all <- executeChecks(cdm = cdm,
+                          ingredients = 1125315,
+                          subsetToConceptId = NULL)
+
+  expect_true(all(result_all$conceptSummary$drug_concept_id %in%
+    c(40162522, 1127078)))
+
+
+  result_subset <- executeChecks(cdm = cdm,
+                              ingredients = 1125315,
+                              subsetToConceptId = 40162522)
+  expect_true(all(result_subset$conceptSummary$drug_concept_id %in%
+                    c(40162522)))
+
+  result_subset2 <- executeChecks(cdm = cdm,
+                                 ingredients = 1125315,
+                                 subsetToConceptId = c(40162522, 1127078))
+
+  expect_true(all(result_subset2$conceptSummary$drug_concept_id %in%
+                    c(40162522, 1127078)))
+
+  DBI::dbDisconnect(attr(cdm, "dbcon"), shutdown = TRUE)
+})
